@@ -1,5 +1,4 @@
-from .generator import *
 from .image_color_transform import *
 from .image_info import *
 from .image_transform import *
-from .optional import *
+from .image_slice import *
